@@ -527,7 +527,31 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         self.assertEqual(delivery_address.postal_code, '00100')
         self.assertEqual(delivery_address.city, 'Helsinki')
         self.assertEqual(delivery_address.country, '')
+        self.assertEqual(delivery_address.post_office_box, '')
 
+    def test_delivery_party_name(self):
+        """
+        test_invoice_delivery_organisation_name
+
+        invoice.delivery_contact_phone contains the value from the
+        <DeliveryOrganisationName> element.
+        """
+        invoice_recipient = self.wrapper.invoice_recipient
+        self.assertEqual(invoice_recipient.organisation_name, u'Tilitoimisto Ryynänen')
+
+    def test_invoice_recipient_party_address(self):
+        """
+        test_delivery_party_address
+
+        delivery_party.address contain the collected values from the
+        DeliveryPostalAddressDetails aggregate.
+        """
+        invoice_recipient = self.wrapper.invoice_recipient.address
+        self.assertEqual(invoice_recipient.street_name, u'Mäkelänkatu 2')
+        self.assertEqual(invoice_recipient.postal_code, '00102')
+        self.assertEqual(invoice_recipient.city, 'Helsinki')
+        self.assertEqual(invoice_recipient.country, 'FINLAND')
+        self.assertEqual(invoice_recipient.post_office_box, 'PL 22')
 
 class TestFinvoiceWrapperWithPankkiyhdistysFinvoice(FinvoiceTestCase):
     """
