@@ -184,6 +184,11 @@ class PostalAddress(object):
         if country and len(country) > 0:
             self.country = country[0].text or ''
 
+        name = self.node_prefix + 'PostOfficeBoxIdentifier'
+        post_office_box = element_node.get_children_by_name(name)
+        if post_office_box and len(post_office_box) > 0:
+            self.post_office_box = post_office_box[0].text or ''
+
 
 class SellerPostalAddress(PostalAddress):
     node_prefix = 'Seller'
@@ -196,6 +201,40 @@ class BuyerPostalAddress(PostalAddress):
 class DeliveryAddress(PostalAddress):
     node_prefix = 'Delivery'
 
+class InvoiceRecipientAddress(PostalAddress):
+    node_prefix = 'InvoiceRecipient'
+
+class InvoiceRecipient(object):
+    organisation_name = ''
+    party_identifier = ''
+    tax_code = ''
+    address = None
+
+    def __init__(self, doc):
+        self.address = InvoiceRecipientAddress()
+
+        invoice_recipient_party_details = doc.InvoiceRecipientPartyDetailsSet
+        if len(invoice_recipient_party_details) > 0:
+            postal_address = \
+                invoice_recipient_party_details[0].InvoiceRecipientPostalAddressDetailsSet
+            if len(postal_address) > 0:
+                self.address = InvoiceRecipientAddress(postal_address[0])
+
+            party_identifier = \
+                invoice_recipient_party_details[0].InvoiceRecipientPartyIdentifierSet
+            if len(party_identifier) > 0:
+                self.party_identifier = party_identifier[0].text
+
+            organisation_name = \
+                invoice_recipient_party_details[0].InvoiceRecipientOrganisationNameSet
+            if len(organisation_name) > 0:
+                self.organisation_name = organisation_name[0].text
+
+            tax_code = \
+                invoice_recipient_party_details[0].InvoiceRecipientOrganisationTaxCodeSet
+            if len(tax_code) > 0:
+                self.tax_code = organisation_name[0].text
+
 
 class DeliveryParty(object):
     contact_email = ''
@@ -553,6 +592,7 @@ class FinvoiceWrapper(object):
     payee = None
     payer = None
     delivery_party = None
+    invoice_recipient = None
     invoice = None
     rows = None
     errors = None
@@ -566,6 +606,7 @@ class FinvoiceWrapper(object):
         self.payee = Payee(doc, envelope)
         self.payer = Payer(doc, envelope)
         self.delivery_party = DeliveryParty(doc)
+        self.invoice_recipient = InvoiceRecipient(doc)
         self.invoice = Invoice(doc)
         self.rows = self.get_rows(doc)
         self.version = doc.version
